g4f - gui
Description: A conversational AI system that listens, learns, and challenges

discord ~ discord.gg/qXA4Wf4Fsm
github ~ @xtekky/gpt4free

### Settings

Enable Dark Mode
Web Access with DuckDuckGo
Disable Conversation History
Hide System-prompt
Download generated images
Refine files with spaCy
Input max. height
Speech recognition language
Microsoft Designer in Bing:
Cerebras Inference:
Anthropic API:
DeepInfra:
Gemini API:
Groq:
glhf.chat:
HuggingFace:
OpenAI API:
OpenRouter:
Perplexity API:
Replicate:
xAI: